# Oli

Oli is a one liner installer aimed at easing you with the installation of everything you need on different platforms. With no packages needed

## Installation

Run `pip install oli`

or 

```Bash
git clone https://github.com/StanGirard/Oli
cd Oli
```

## Usage 

Run in your bash `oli`

or 

`python3 -m oli.run`

## Programs

### Linux

- Netdata

### Macos

-  Homebrew
-  Oh My Zsh
-  Xcode Command Line
-  Development Setup




